<!--

@license Apache-2.0

Copyright (c) 2024 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# join

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Return a string created by joining array elements using a specified separator.

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/array-base-join
```

</section>

<section class="usage">

## Usage

```javascript
var join = require( '@stdlib/array-base-join' );
```

#### join( x, separator )

Returns a string created by joining array elements using a specified separator.

```javascript
var x = [ 1, 2, 3, 4, 5, 6 ];

var out = join( x, ',' );
// returns '1,2,3,4,5,6'
```

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

## Notes

-   If provided an array-like object having a `join` method, the function defers execution to that method and assumes that the method API has the following signature:

    ```text
    x.join( separator )
    ```

-   If provided an array-like object without a `join` method, the function manually constructs the output string.

-   If an array element is either `null` or `undefined`, the function will serialize the element as an empty string.

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var Complex128Array = require( '@stdlib/array-complex128' );
var Complex64Array = require( '@stdlib/array-complex64' );
var AccessorArray = require( '@stdlib/array-base-accessor' );
var Float64Array = require( '@stdlib/array-float64' );
var join = require( '@stdlib/array-base-join' );

var x = [ 0, 1, 2, 3, 4, 5 ];
var s = join( x, ',' );
// returns '0,1,2,3,4,5'

x = new Float64Array( [ 0.0, 1.0, 2.0, 3.0, 4.0, 5.0 ] );
s = join( x, ',' );
// returns '0,1,2,3,4,5'

s = join( x, '-' );
// returns '0-1-2-3-4-5'

x = new AccessorArray( [ 1, 2, 3, 4 ] );
s = join( x, ',' );
// returns '1,2,3,4'

x = new Complex128Array( [ 1.0, 2.0, 3.0, 4.0, 5.0, 6.0 ] );
s = join( x, ',' );
// returns '1 + 2i,3 + 4i,5 + 6i'

x = new Complex64Array( [ 1.0, -1.0, 2.0, -2.0 ] );
s = join( x, ',' );
// returns '1 - 1i,2 - 2i'
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2024. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/array-base-join.svg
[npm-url]: https://npmjs.org/package/@stdlib/array-base-join

[test-image]: https://github.com/stdlib-js/array-base-join/actions/workflows/test.yml/badge.svg?branch=v0.1.1
[test-url]: https://github.com/stdlib-js/array-base-join/actions/workflows/test.yml?query=branch:v0.1.1

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/array-base-join/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/array-base-join?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/array-base-join.svg
[dependencies-url]: https://david-dm.org/stdlib-js/array-base-join/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/array-base-join/tree/deno
[deno-readme]: https://github.com/stdlib-js/array-base-join/blob/deno/README.md
[umd-url]: https://github.com/stdlib-js/array-base-join/tree/umd
[umd-readme]: https://github.com/stdlib-js/array-base-join/blob/umd/README.md
[esm-url]: https://github.com/stdlib-js/array-base-join/tree/esm
[esm-readme]: https://github.com/stdlib-js/array-base-join/blob/esm/README.md
[branches-url]: https://github.com/stdlib-js/array-base-join/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/array-base-join/main/LICENSE

</section>

<!-- /.links -->
